#include "xscugic.h"

XScuGic_Config XScuGic_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {

	{
		"arm,gic-v3", /* compatible */
		0xe2000000,
		0xe2100000, /* reg */
		{{0U}} /* Handler-table */
	},
	 {
		 NULL
	}
};